@@ -147,9 +147,16 @@ class AsyncClient:
         res: RPCResponse = await self.http.send(data)
         return res
 
-    async def get_supply(self) -> RPCResponse:
+    async def get_genesis_hash(self) -> RPCResponse:
         data: dict[str, Any] = self.http.build_data(
-            method="getSupply", params=[None]
+            method="getGenesisHash", params=[None]
+        )
+        res: RPCResponse = await self.http.send(data)
+        return res
+
+    async def get_health(self) -> RPCResponse:
+        data: dict[str, Any] = self.http.build_data(
+            method="getHealth", params=[None]
         )
         res: RPCResponse = await self.http.send(data)
         return res
@@ -161,9 +168,72 @@ class AsyncClient:
         res: RPCResponse = await self.http.send(data)
         return res
 
-    async def get_transaction(self, signature: str) -> RPCResponse:
+    async def get_inflation_governor(self) -> RPCResponse:
         data: dict[str, Any] = self.http.build_data(
-            method="getTransaction", params=[signature]
+            method="getInflationGovernor", params=[None]
+        )
+        res: RPCResponse = await self.http.send(data)
+        return res
+    
+    async def get_inflation_rate(self) -> RPCResponse:
+        data: dict[str, Any] = self.http.build_data(
+            method="getInflationRate", params=[None]
+        )
+        res: RPCResponse = await self.http.send(data)
+        return res
+
+    async def get_inflation_reward(self , addresses: list[str]) -> RPCResponse:
+        data: dict[str, Any] = self.http.build_data(
+            method="getInflationReward", params=[addresses]
+        )
+        res: RPCResponse = await self.http.send(data)
+        return res
+
+    async def get_largest_accounts(self) -> RPCResponse:
+        data: dict[str, Any] = self.http.build_data(
+            method="getLargestAccounts", params=[None]
+        )
+        res: RPCResponse = await self.http.send(data)
+        return res
+
+    async def get_leader_schedule(self) -> RPCResponse:
+        data: dict[str, Any] = self.http.build_data(
+            method="getLeaderSchedule", params=[None]
+        )
+        res: RPCResponse = await self.http.send(data)
+        return res
+
+    async def get_max_retransmit_slot(self) -> RPCResponse:
+        data: dict[str, Any] = self.http.build_data(
+            method="getMaxRetransmitSlot", params=[None]
+        )
+        res: RPCResponse = await self.http.send(data)
+        return res
+    
+    async def get_max_shred_insert_slot(self) -> RPCResponse:
+        data: dict[str, Any] = self.http.build_data(
+            method="getMaxShredInsertSlot", params=[None]
+        )
+        res: RPCResponse = await self.http.send(data)
+        return res
+   
+    async def get_minimum_balance_for_rent_exemption(self, acct_length: int) -> RPCResponse:
+        data: dict[str, Any] = self.http.build_data(
+            method="getMinimumBalanceForRentExemption", params=[acct_length]
+        )
+        res: RPCResponse = await self.http.send(data)
+        return res
+
+    async def get_multiple_accounts(self, pubkeys: list) -> RPCResponse:
+        data: dict[str, Any] = self.http.build_data(
+            method="getMultipleAccounts", params=[pubkeys]
+        )
+        res: RPCResponse = await self.http.send(data)
+        return res
+    
+    async def get_program_accounts(self, public_key: PublicKey) -> RPCResponse:
+        data: dict[str, Any] = self.http.build_data(
+            method="getProgramAccounts", params=[public_key]
         )
         res: RPCResponse = await self.http.send(data)
         return res
@@ -175,6 +245,41 @@ class AsyncClient:
         )
         res: RPCResponse = await self.http.send(data)
         return res
+    
+    async def get_recent_performance_samples(self) -> RPCResponse:
+        data: dict[str, Any] = self.http.build_data(
+            method="getRecentPerformanceSamples", params=[None]
+        )
+        res: RPCResponse = await self.http.send(data)
+        return res
+
+    async def get_signatures_for_address(self, acct_address: str) -> RPCResponse:
+        data: dict[str, Any] = self.http.build_data(
+            method="getSignaturesForAddress", params=[acct_address]
+        )
+        res: RPCResponse = await self.http.send(data)
+        return res
+        
+    async def get_signature_statuses(self, transaction_sigs: list[str]) -> RPCResponse:
+        data: dict[str, Any] = self.http.build_data(
+            method="getSignatureStatuses", params=[transaction_sigs]
+        )
+        res: RPCResponse = await self.http.send(data)
+        return res 
+        
+    async def get_slot(self) -> RPCResponse:
+        data: dict[str, Any] = self.http.build_data(
+            method="getSlot", params=[None]
+        )
+        res: RPCResponse = await self.http.send(data)
+        return res
+
+    async def get_supply(self) -> RPCResponse:
+        data: dict[str, Any] = self.http.build_data(
+            method="getSupply", params=[None]
+        )
+        res: RPCResponse = await self.http.send(data)
+        return res
 
     async def get_token_accounts_by_owner(self, public_key: str | PublicKey,
                                     **kwargs) -> RPCResponse:
@@ -198,6 +303,14 @@ class AsyncClient:
         res: RPCResponse = await self.http.send(data)
         return res
 
+    async def get_transaction(self, signature: str) -> RPCResponse:
+        data: dict[str, Any] = self.http.build_data(
+            method="getTransaction", params=[signature]
+        )
+        res: RPCResponse = await self.http.send(data)
+        return res
+
+    # Non "get" methods
     async def request_airdrop(self, public_key: PublicKey | str, lamports: int
                         ) -> RPCResponse:
 
@@ -208,12 +321,10 @@ class AsyncClient:
         res: RPCResponse = await self.http.send(data)
         return res
 
-    async def send_transaction(self, transaction: Transaction,
-                         recent_blockhash: str | None = None
-                         ) -> RPCResponse:
+    async def send_transaction(self, transaction: Transaction) -> RPCResponse:
 
-        if recent_blockhash is None:
-            blockhash_resp = await self.get_recent_blockhash()
+        if transaction.recent_blockhash is None:
+            blockhash_resp = self.get_recent_blockhash()
             recent_blockhash = blockhash_resp["result"]["value"]["blockhash"]
 
         transaction.recent_blockhash = recent_blockhash
@@ -224,4 +335,4 @@ class AsyncClient:
             params=[transaction.serialize(), {"encoding": "base64"}]
         )
         res: RPCResponse = await self.http.send(data)
-        return res
+        return res
\ No newline at end of file
